Utilities
---------

.. currentmodule:: yaw

Most `yet_another_wizz` code produces detailed log messages. These can be
filtered and collected easily on standard output or in a log file using the
following utility function:

.. autosummary::
    :toctree: autogen

    utils.get_logger


Additionally, there is a special container with convenience methods that store
bin intervals:

.. autosummary::
    :toctree: autogen

    Binning
